from django.apps import AppConfig


class ImpostorConfig(AppConfig):
    name = 'impostor'
    verbose_name = 'Impostor'
